/*
		     Endeavour Devices List File IO
 */

#ifndef EDV_DEVICES_LIST_H
#define EDV_DEVICES_LIST_H

#include <glib.h>
#include "edv_device.h"


extern void EDVDevicesListUpdateMountStatesFromSystem(
	edv_device_struct **list, const gint total
);

extern edv_device_struct **EDVDevicesListFileOpen(
	const gchar *filename, gint *total
);
extern void EDVDeviceListFileSave(
	const gchar *filename,
	edv_device_struct **list, const gint total
);


#endif	/* EDV_DEVICES_LIST_H */
